==> zio-aws-s3_2.12-5.19.7.5-sources.jar: zio/aws/s3/model/GetBucketOwnershipControlsResponse.scala <==
package zio.aws.s3.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetBucketOwnershipControlsResponse(
    ownershipControls: Optional[zio.aws.s3.model.OwnershipControls] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.GetBucketOwnershipControlsResponse = {
    import GetBucketOwnershipControlsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.GetBucketOwnershipControlsResponse
      .builder()
      .optionallyWith(ownershipControls.map(value => value.buildAwsValue()))(
        _.ownershipControls
      )
      .build()
  }
  def asReadOnly: zio.aws.s3.model.GetBucketOwnershipControlsResponse.ReadOnly =
    zio.aws.s3.model.GetBucketOwnershipControlsResponse.wrap(buildAwsValue())
}
object GetBucketOwnershipControlsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.GetBucketOwnershipControlsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.GetBucketOwnershipControlsResponse =
      zio.aws.s3.model.GetBucketOwnershipControlsResponse(
        ownershipControls.map(value => value.asEditable)
      )
    def ownershipControls: Optional[zio.aws.s3.model.OwnershipControls.ReadOnly]
    def getOwnershipControls
        : ZIO[Any, AwsError, zio.aws.s3.model.OwnershipControls.ReadOnly] =
      AwsError.unwrapOptionField("ownershipControls", ownershipControls)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.GetBucketOwnershipControlsResponse
  ) extends zio.aws.s3.model.GetBucketOwnershipControlsResponse.ReadOnly {
    override val ownershipControls
        : Optional[zio.aws.s3.model.OwnershipControls.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ownershipControls())
        .map(value => zio.aws.s3.model.OwnershipControls.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.GetBucketOwnershipControlsResponse
  ): zio.aws.s3.model.GetBucketOwnershipControlsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-s3_3-5.17.158.4-sources.jar: zio/aws/s3/model/GetBucketOwnershipControlsResponse.scala <==
package zio.aws.s3.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetBucketOwnershipControlsResponse(
    ownershipControls: Option[zio.aws.s3.model.OwnershipControls] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.GetBucketOwnershipControlsResponse = {
    import GetBucketOwnershipControlsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.GetBucketOwnershipControlsResponse
      .builder()
      .optionallyWith(ownershipControls.map(value => value.buildAwsValue()))(
        _.ownershipControls
      )
      .build()
  }
  def asReadOnly: zio.aws.s3.model.GetBucketOwnershipControlsResponse.ReadOnly =
    zio.aws.s3.model.GetBucketOwnershipControlsResponse.wrap(buildAwsValue())
}
object GetBucketOwnershipControlsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.GetBucketOwnershipControlsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.GetBucketOwnershipControlsResponse =
      zio.aws.s3.model.GetBucketOwnershipControlsResponse(
        ownershipControls.map(value => value.asEditable)
      )
    def ownershipControls: Option[zio.aws.s3.model.OwnershipControls.ReadOnly]
    def getOwnershipControls
        : ZIO[Any, AwsError, zio.aws.s3.model.OwnershipControls.ReadOnly] =
      AwsError.unwrapOptionField("ownershipControls", ownershipControls)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.GetBucketOwnershipControlsResponse
  ) extends zio.aws.s3.model.GetBucketOwnershipControlsResponse.ReadOnly {
    override val ownershipControls
        : Option[zio.aws.s3.model.OwnershipControls.ReadOnly] = scala
      .Option(impl.ownershipControls())
      .map(value => zio.aws.s3.model.OwnershipControls.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.GetBucketOwnershipControlsResponse
  ): zio.aws.s3.model.GetBucketOwnershipControlsResponse.ReadOnly = new Wrapper(
    impl
  )
}
